Method: Ronin::Script::InstanceMethods#load_script!

Defined in:
lib/ronin/script/script.rb

#load_script!Boolean

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Loads the code from the cached file for the object, and instance evaluates it into the object.

Returns:

  • (Boolean)

    Indicates the original code was successfully loaded.

Since:

  • 1.1.0



224
225
226
227
228
229
230
231
232
233
234
# File 'lib/ronin/script/script.rb', line 224

def load_script!
  if (cached? && !script_loaded?)
    block = self.class.load_object_block(self.script_path.path)

    @script_loaded = true
    instance_eval(&block) if block
    return true
  end

  return false
end